==> zither-1.1.14.tar.gz: zither_prj/apollon/config_upnew.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(2)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

require("./socket.inc");
require("./list_file_upload.inc");

$C_NAME = $_GET["C_NAME"]; 
$CIP = $_GET["CIP"]; 
$C_INFO = $_GET["C_INFO"];
$SOCK_IPADDR = $_GET["SOCK_IPADDR"]; 
$SOCK2_IPADDR = $_GET["SOCK2_IPADDR"];
$SOCK_PORT = $_GET["SOCK_PORT"];
$SOCK2_PORT = $_GET["SOCK2_PORT"];
$BAT_FILE = $_GET["BAT_FILE"];
$BAT2_FILE = $_GET["BAT2_FILE"];
$COMMAND_PATH = $_GET["COMMAND_PATH"];
$BAT_INT = $_GET["BAT_INT"];
$BAT2_INT = $_GET["BAT2_INT"];
$LIFE_INT = $_GET["LIFE_INT"];
$LIFE_LOS =  $_GET["LIFE_LOS"];
$MAIL_CC = $_GET["MAIL_CC"]; 
$UPDATE_COM = $_GET["UPDATE_COM"]; 
$GEN = $_GET["GEN"];

$COM_MONITOR = $_GET["COM_MONITOR"]; 

$C_BLOCK_NAME = $C_NAME . "-default";

$UP_TIME = date("Y m d g i s A");   

print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("ƻ륯饤 $CNAME εưեԽǤޤ\n");


if(0 == strlen($C_NAME)){
   print("NOT hostname");
   exit;
   }
if(0 == strlen($CIP)){
   print("NOT client ip");
   exit;
   }


$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
echo "NG DB³ޤ<br>";
   exit;
   }


$result = pg_query($conn, "select * from connection where cname='$C_NAME';");
if(!$result){
   print("NG 䤤碌Ǥ\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   print("NG Ǥ˥ǡ¸ߤޤ\n");
   exit;
   }


$result = pg_query($conn, "select * from config where c_name='$C_NAME';");
if(!$result){
   print("NG 䤤碌Ǥ 1\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   $result = pg_query($conn, "update config set
    c_name='$C_NAME',
    c_info='$C_INFO',
    sock_ipaddr='$SOCK_IPADDR',
    sock_port='$SOCK_PORT',
    sock2_ipaddr='$SOCK2_IPADDR',
    sock2_port='$SOCK2_PORT',
    bat_file='$BAT_FILE',
    bat2_file='$BAT2_FILE',
    command_path='$COMMAND_PATH',
    bat_int=$BAT_INT,
    bat2_int=$BAT2_INT,
    life_int=$LIFE_INT,
    life_los=$LIFE_LOS,
    mail_cc='$MAIL_CC',
    update_com='$UPDATE_COM',
    up_time='$UP_TIME'
    where c_name='$C_NAME'");

   if(!$result){
      print("NG ǡ϶äݤǤ\n");
      exit;
      }
   }
else{
   $result = pg_query($conn, "insert into config values (
    '$C_NAME',
    '$C_INFO',
    '$SOCK_IPADDR',
    '$SOCK_PORT',
    '$SOCK2_IPADDR',
    '$SOCK2_PORT',
    '$BAT_FILE',
    '$BAT2_FILE',
    '$COMMAND_PATH',
    $BAT_INT,
    $BAT2_INT,
    $LIFE_INT,
    $LIFE_LOS,
    '$MAIL_CC',
    '$UPDATE_COM',
    '$UP_TIME'
    )");

   if(!$result){
      print("NG ְä꡼Ǥ1\n");
      exit;
      }
   }


$result = pg_query($conn, "select * from connection where cname='$C_NAME';");
if(!$result){
   print("NG 䤤碌Ǥ 2\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   $result = pg_query($conn, "update connection set
    cname='$C_NAME',
    cip='$CIP'
    where cname='$C_NAME'");

   if(!$result){
      print("NG ְä꡼Ǥ2\n");
      exit;
      }
   print("connection.sql˥ǡ¸ߤޤ񤭤ޤ\n");
   }

else{
   $result = pg_query($conn, "insert into connection values (
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    '$C_NAME',
    '$CIP',
    'NOT',
    'NOT',
    'FREE')
    ");
   if(!$result){
      print("NG ְä꡼Ǥ3\n");
      exit;
      }
   print("ͥDB $C_NAME ʤΤǿɲ\n");
   }



$start_file = "/usr/local/zither/conf/$C_NAME.conf";
$result = pg_query($conn, "select * from config where c_name='$C_NAME';");
if(!$result){
   print("NG ְä꡼Ǥ4\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   if(($fp = fopen($start_file, "w+"))==NULL){
      print("NG file not open $start_file\n");
      exit;
      }
   $s = 0;
   while($s < $num){
      $DATA = rtrim(pg_fetch_Result($result, $s, c_name));
      if(0 != strlen($DATA)){ fwrite($fp, "C_NAME:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, c_info));
      if(0 != strlen($DATA)){ fwrite($fp, "C_INFO:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, sock_ipaddr));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK_IPADDR:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, sock2_ipaddr));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_IPADDR:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, sock_port));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK_PORT:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, sock2_port));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_PORT:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, bat_file));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT_FILE:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, bat2_file));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT2_FILE:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, command_path));
      if(0 != strlen($DATA)){ fwrite($fp, "COMMAND_PATH:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, bat_int));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT_INT:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, bat2_int));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT2_INT:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, life_int));
      if(0 != strlen($DATA)){ fwrite($fp, "LIFE_INT:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, life_los));
      if(0 != strlen($DATA)){ fwrite($fp, "LIFE_LOS:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, mail_cc));
      if(0 != strlen($DATA)){ fwrite($fp, "MAIL_CC:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, update_com));
      if(0 != strlen($DATA)){ fwrite($fp, "UPDATE_COM:$DATA\n"); }
      $DATA = rtrim(pg_fetch_Result($result, $s, up_time));

      $s++;
      }

   fclose($fp);

   echo "$C_NAME.conf file update ok\n";
   echo " \n";
   }
else{
   echo "$C_NAME.conf file not update!!\n";
   echo "ԤǤ \n";
   }




$result = pg_query($conn, "select * from monitor where cname='$C_NAME';");
if(!$result){
   print("bud query set(select)\n");
   exit;
   }
$num = pg_num_rows($result);
if($num < 1){

   if(0 == strcmp($COM_MONITOR, "ON")){   

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'dfc.sh none 90', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'inode.sh none 40', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'uptime.sh 40', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'freemem.sh 1000', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }        

      print("OK ƻ֥åޤ\n");
      $result = pg_query($conn, "insert into userblock values (
        'test',
        '$C_BLOCK_NAME',
        '$C_NAME',
        'ON',
        'NON',
        60,
        0,
        0,
        'test@localhost',
        'test@localhost',
        '˽ƻѤƤ',
        'NOT',
        'NOT'
      )");
      if(!$result){
         print("NG ƻ֥åޤǤ\n");
         exit;
         }
      }

   pg_free_result($result);

   echo "OK Inser data\n";
   echo "$C_NAME\n";
   echo "$CIP\n";
   }






$conf_file = "/usr/local/zither/conf/$C_NAME.stat";
if(($fp = fopen($conf_file, "w+"))==NULL){
   print("stat file not open\n");
   exit;
   }
$result = pg_query($conn, "select * from connection where cname='$C_NAME'");
if(!$result){
   print("bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num <= 0){
   print("no data\n");
   fwrite($fp, "START");
   echo "stat file update ok(START)\n";
   echo " \n";
   }
else{
   $s = 0;
   while($s < $num){
      $MODE = rtrim(pg_fetch_Result($result, $s, mode));
      fwrite($fp, $MODE);
      echo "stat file update ok\n";
      echo " \n";
      $s++;
      }
   }

fclose($fp);




$conf_file = "/usr/local/zither/conf/$C_NAME.command";
if(($fp = fopen($conf_file, "w+"))==NULL){
   print("$conf_file file not open\n");
   exit;
   }
else{
   $conf_file2 = "/usr/local/zither/conf/test.command";
   if(($fp2 = fopen($conf_file2, "r+"))!=NULL){
      print("write open file name $conf_file \n");
      print("read open file name $conf_file2 \n");
      while(1){
         $file_data = fgets($fp2, 2048);
         fwrite($fp, "$file_data");
         if(0 == strcmp($file_data, NULL)){
            break;
            }
         }
      fclose($fp2);
      }
   else{
      fwrite($fp, "##\n");
      fwrite($fp, "##\n");
      fclose($fp);
      }
   }


echo "command file update ok\n";
echo " \n";


$conf_file = "/usr/local/zither/conf/neg.conf";
$result = pg_query($conn, "select * from connection");
if(!$result){
   print("bud query conection\n");
   exit;
   }$num = pg_num_rows($result);
if($num <= 0){
   print("no data conection\n");
   exit;
   }
if(($fp = fopen($conf_file, "w+"))==NULL){
   print("file not open neg.conf\n");
   exit;   }  
$s = 0;
while($s < $num){
   $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
   $CIP = rtrim(pg_fetch_Result($result, $s, cip));
   fwrite($fp, "$CNAME:$CIP\n");
   print("$CNAME:$CIP\n");
   $s++;
   }
fclose($fp);
echo "neg.conf file update ok\n";
echo " \n";




list_file_upload($C_NAME, $GEN);




pg_free_result($result);
pg_Close($conn);

print("</font>");

?>

</pre>
</body>
</html>

==> zither-1.1.15.tar.gz: zither_prj/apollon/config_upnew.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(2)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";


$C_NAME = enco($_GET["C_NAME"]);
$CIP = enco($_GET["CIP"]); 
$C_INFO = enco($_GET["C_INFO"]);
$SOCK_IPADDR = enco($_GET["SOCK_IPADDR"]); 
$SOCK2_IPADDR = enco($_GET["SOCK2_IPADDR"]);
$SOCK_PORT = enco($_GET["SOCK_PORT"]);
$SOCK2_PORT = enco($_GET["SOCK2_PORT"]);
$BAT_FILE = enco($_GET["BAT_FILE"]);
$BAT2_FILE = enco($_GET["BAT2_FILE"]);
$COMMAND_PATH = enco($_GET["COMMAND_PATH"]);
$BAT_INT = enco($_GET["BAT_INT"]);
$BAT2_INT = enco($_GET["BAT2_INT"]);
$LIFE_INT = enco($_GET["LIFE_INT"]);
$LIFE_LOS =  enco($_GET["LIFE_LOS"]);
$MAIL_CC = enco($_GET["MAIL_CC"]); 
$UPDATE_COM = enco($_GET["UPDATE_COM"]); 
$GEN = enco($_GET["GEN"]);

$COM_MONITOR = enco($_GET["COM_MONITOR"]); 

$C_BLOCK_NAME = $C_NAME . "-default";

$UP_TIME = date("Y m d g i s A");   



print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("ƻ륯饤 $CNAME εưեԽǤޤ\n");


if(0 == strlen($C_NAME)){
   print("NOT hostname");
   exit;
   }
if(0 == strlen($CIP)){
   print("NOT client ip");
   exit;
   }


$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
echo "NG DB³ޤ<br>";
   exit;
   }


$result = pg_query($conn, "select * from connection where cname='$C_NAME';");
if(!$result){
   print("NG 䤤碌Ǥ\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   print("NG Ǥ˥ǡ¸ߤޤ\n");
   exit;
   }


$result = pg_query($conn, "select * from config where c_name='$C_NAME';");
if(!$result){
   print("NG 䤤碌Ǥ 1\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   $result = pg_query($conn, "update config set
    c_name='$C_NAME',
    c_info='$C_INFO',
    sock_ipaddr='$SOCK_IPADDR',
    sock_port='$SOCK_PORT',
    sock2_ipaddr='$SOCK2_IPADDR',
    sock2_port='$SOCK2_PORT',
    bat_file='$BAT_FILE',
    bat2_file='$BAT2_FILE',
    command_path='$COMMAND_PATH',
    bat_int=$BAT_INT,
    bat2_int=$BAT2_INT,
    life_int=$LIFE_INT,
    life_los=$LIFE_LOS,
    mail_cc='$MAIL_CC',
    update_com='$UPDATE_COM',
    up_time='$UP_TIME'
    where c_name='$C_NAME'");

   if(!$result){
      print("NG ǡ϶äݤǤ\n");
      exit;
      }
   }
else{
   $result = pg_query($conn, "insert into config values (
    '$C_NAME',
    '$C_INFO',
    '$SOCK_IPADDR',
    '$SOCK_PORT',
    '$SOCK2_IPADDR',
    '$SOCK2_PORT',
    '$BAT_FILE',
    '$BAT2_FILE',
    '$COMMAND_PATH',
    $BAT_INT,
    $BAT2_INT,
    $LIFE_INT,
    $LIFE_LOS,
    '$MAIL_CC',
    '$UPDATE_COM',
    '$UP_TIME'
    )");

   if(!$result){
      print("NG ְä꡼Ǥ1\n");
      exit;
      }
   }


$result = pg_query($conn, "select * from connection where cname='$C_NAME';");
if(!$result){
   print("NG 䤤碌Ǥ 2\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   $result = pg_query($conn, "update connection set
    cname='$C_NAME',
    cip='$CIP'
    where cname='$C_NAME'");

   if(!$result){
      print("NG ְä꡼Ǥ2\n");
      exit;
      }
   print("connection.sql˥ǡ¸ߤޤ񤭤ޤ\n");
   }

else{
   $result = pg_query($conn, "insert into connection values (
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    '$C_NAME',
    '$CIP',
    'NOT',
    'NOT',
    'FREE')
    ");
   if(!$result){
      print("NG ְä꡼Ǥ3\n");
      exit;
      }
   print("ͥDB $C_NAME ʤΤǿɲ\n");
   }



$start_file = "/usr/local/zither/conf/$C_NAME.conf";
$result = pg_query($conn, "select * from config where c_name='$C_NAME';");
if(!$result){
   print("NG ְä꡼Ǥ4\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   if(($fp = fopen($start_file, "w+"))==NULL){
      print("NG file not open $start_file\n");
      exit;
      }
   $s = 0;
   while($s < $num){
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, c_name));
      if(0 != strlen($DATA)){ fwrite($fp, "C_NAME:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, c_info));
      if(0 != strlen($DATA)){ fwrite($fp, "C_INFO:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock_ipaddr));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK_IPADDR:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock2_ipaddr));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_IPADDR:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock_port));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK_PORT:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock2_port));
      if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_PORT:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat_file));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT_FILE:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat2_file));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT2_FILE:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, command_path));
      if(0 != strlen($DATA)){ fwrite($fp, "COMMAND_PATH:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat_int));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT_INT:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat2_int));
      if(0 != strlen($DATA)){ fwrite($fp, "BAT2_INT:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, life_int));
      if(0 != strlen($DATA)){ fwrite($fp, "LIFE_INT:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, life_los));
      if(0 != strlen($DATA)){ fwrite($fp, "LIFE_LOS:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, mail_cc));
      if(0 != strlen($DATA)){ fwrite($fp, "MAIL_CC:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, update_com));
      if(0 != strlen($DATA)){ fwrite($fp, "UPDATE_COM:$DATA\n"); }
      $DATA = enco_rtrim(pg_fetch_Result($result, $s, up_time));

      $s++;
      }

   fclose($fp);

   echo "$C_NAME.conf file update ok\n";
   echo " \n";
   }
else{
   echo "$C_NAME.conf file not update!!\n";
   echo "ԤǤ \n";
   }




$result = pg_query($conn, "select * from monitor where cname='$C_NAME';");
if(!$result){
   print("bud query set(select)\n");
   exit;
   }
$num = pg_num_rows($result);
if($num < 1){

   if(0 == strcmp($COM_MONITOR, "ON")){   

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'dfc.sh none 90', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'inode.sh none 40', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'uptime.sh 40', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }

      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'freemem.sh 1000', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
      if(!$result){
         print("bud query set\n");
         exit;
         }        

      print("OK ƻ֥åޤ\n");
      $result = pg_query($conn, "insert into userblock values (
        'test',
        '$C_BLOCK_NAME',
        '$C_NAME',
        'ON',
        'NON',
        60,
        0,
        0,
        'test@localhost',
        'test@localhost',
        'It corrects it. ',
        'NOT',
        'NOT'
      )");
      if(!$result){
         print("NG ƻ֥åޤǤ\n");
         exit;
         }
      }

   pg_free_result($result);

   echo "OK Inser data\n";
   echo "$C_NAME\n";
   echo "$CIP\n";
   }






$conf_file = "/usr/local/zither/conf/$C_NAME.stat";
if(($fp = fopen($conf_file, "w+"))==NULL){
   print("stat file not open\n");
   exit;
   }
$result = pg_query($conn, "select * from connection where cname='$C_NAME'");
if(!$result){
   print("bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num <= 0){
   print("no data\n");
   fwrite($fp, "START");
   echo "stat file update ok(START)\n";
   echo " \n";
   }
else{
   $s = 0;
   while($s < $num){
      $MODE = enco_rtrim(pg_fetch_Result($result, $s, mode));
      fwrite($fp, $MODE);
      echo "stat file update ok\n";
      echo " \n";
      $s++;
      }
   }

fclose($fp);




$conf_file = "/usr/local/zither/conf/$C_NAME.command";
if(($fp = fopen($conf_file, "w+"))==NULL){
   print("$conf_file file not open\n");
   exit;
   }
else{
   $conf_file2 = "/usr/local/zither/conf/test.command";
   if(($fp2 = fopen($conf_file2, "r+"))!=NULL){
      print("write open file name $conf_file \n");
      print("read open file name $conf_file2 \n");
      while(1){
         $file_data = fgets($fp2, 2048);
         fwrite($fp, "$file_data");
         if(0 == strcmp($file_data, NULL)){
            break;
            }
         }
      fclose($fp2);
      }
   else{
      fwrite($fp, "##\n");
      fwrite($fp, "##\n");
      fclose($fp);
      }
   }


echo "command file update ok\n";
echo " \n";


$conf_file = "/usr/local/zither/conf/neg.conf";
$result = pg_query($conn, "select * from connection");
if(!$result){
   print("bud query conection\n");
   exit;
   }$num = pg_num_rows($result);
if($num <= 0){
   print("no data conection\n");
   exit;
   }
if(($fp = fopen($conf_file, "w+"))==NULL){
   print("file not open neg.conf\n");
   exit;   }  
$s = 0;
while($s < $num){
   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
   fwrite($fp, "$CNAME:$CIP\n");
   print("$CNAME:$CIP\n");
   $s++;
   }
fclose($fp);
echo "neg.conf file update ok\n";
echo " \n";




list_file_upload($C_NAME, $GEN);




pg_free_result($result);
pg_Close($conn);

print("</font>");

?>

</pre>
</body>
</html>
